Deprecated List (py4j-java 0.10.9.4 API)
Date: 2022-03-16

Skip navigation links

- Overview
- Package
- Class
- Tree
- Deprecated
- Index
- Help

- Prev
- Next

- Frames
- No Frames

- All Classes

# Deprecated API

## Contents

- Deprecated Methods

- Deprecated Methods
  Method and Description
  py4j.Protocol.getPythonProxyHandler(ClassLoader, Class[], String, Gateway)

Skip navigation links

- Overview
- Package
- Class
- Tree
- Deprecated
- Index
- Help

- Prev
- Next

- Frames
- No Frames

- All Classes